@@ -34,7 +34,7 @@ package Web::MREST;
 
 use 5.012;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use App::CELL qw( $CELL $log $meta $core $site );
 use App::CELL::Test qw( _touch );
@@ -57,11 +57,11 @@ Web::MREST - Minimalistic REST server
 
 =head1 VERSION
 
-Version 0.280
+Version 0.281
 
 =cut
 
-our $VERSION = '0.280';
+our $VERSION = '0.281';
 
 
 =head2 Development status
